@@ -35,7 +35,7 @@ class QueueManager(object):
         elif type(dsn) == str:
             mat = re.match(r'^(.+)://(.+?)(?::(.*)|)@(.+?)(?::(.*?)|)/(.+)', dsn)
             if mat: # is it url arg? (driver://username:password@hostname:port/dbname)
-                driver, username, password, hostname, port, dbname = map(lambda i: mat.group(i), xrange(1,7))
+                driver, username, password, hostname, port, dbname = map(lambda i: mat.group(i), range(1,7))
                 if not (driver in ('postgresql', 'postgres', 'psql', )):
                     raise Exception("Invalid driver (%s). QueueManager supports only 'postgresql://'." % driver)
                 self.dsn = "user=%s host=%s dbname=%s" % (username, hostname, dbname, )
@@ -249,7 +249,7 @@ listen %s;
         for d in self.listen_item(tag, timeout=timeout):
             yield (self.deserializer(d[2]) if d != None else None)
 
-    def dequeue_immediate(self, tag, other_sess = None):
+    def dequeue_item_immediate(self, tag, other_sess = None):
         tag = self.check_tag(tag)
         with self.session(other_sess) as (conn, cur):
             executed = cur.execute(self.select_sql % (tag,))
@@ -257,9 +257,13 @@ listen %s;
             if res:
                 cur.execute(self.ack_sql % (res[0],))
                 if conn: conn.commit()
-                return self.deserializer(res[2])
+                return res
             return res
 
+    def dequeue_immediate(self, tag, other_sess = None):
+        res = self.dequeue_item_immediate(tag, other_sess)
+        return self.deserializer(res[2]) if res else res
+
     def cancel(self, id, other_sess = None):
         with self.session(other_sess) as (conn, cur):
             executed = cur.execute(self.cancel_sql % (id,))
